@@ -1,4 +1,5 @@
 import numpy as np
+import pandas as pd
 
 #########
 # This file has variables and functions that are used by the rest of the package
@@ -44,8 +45,13 @@ def _ReindexCatIds(df, cat_id_index=0):
     like Detectron require starting from 1.
     """
     assert isinstance(cat_id_index, int), "cat_id_index must be an int."
-    df["cat_id"] = df["cat_id"].astype("int")
+    df = df.replace(r"^\s*$", np.nan, regex=True)
+    pd.to_numeric(df["cat_id"])
+
+    #Drop drop rows with NaN cat_id 
+    df2 = df[df.cat_id.notnull()]
+
     # Map cat_ids to the range [cat_id_index, cat_id_index + num_cats)
-    unique_ids = np.sort(df["cat_id"].unique())
+    unique_ids = np.sort(df2["cat_id"].unique())
     ids_dict = dict((v, k) for k, v in enumerate(unique_ids, start=cat_id_index))
     df["cat_id"] = df["cat_id"].map(ids_dict)
